package com.yanzhu.jh.project.mapper;

import java.util.List;
import com.yanzhu.jh.project.domain.SurProjectCheckDetection;

/**
 * 材料送检Mapper接口
 * 
 * @author JiangYuQi
 * @date 2023-08-26
 */
public interface SurProjectCheckDetectionMapper 
{
    /**
     * 查询材料送检
     * 
     * @param id 材料送检主键
     * @return 材料送检
     */
    public SurProjectCheckDetection selectSurProjectCheckDetectionById(Long id);

    /**
     * 查询材料送检列表
     * 
     * @param surProjectCheckDetection 材料送检
     * @return 材料送检集合
     */
    public List<SurProjectCheckDetection> selectSurProjectCheckDetectionList(SurProjectCheckDetection surProjectCheckDetection);

    /**
     * 新增材料送检
     * 
     * @param surProjectCheckDetection 材料送检
     * @return 结果
     */
    public int insertSurProjectCheckDetection(SurProjectCheckDetection surProjectCheckDetection);

    /**
     * 修改材料送检
     * 
     * @param surProjectCheckDetection 材料送检
     * @return 结果
     */
    public int updateSurProjectCheckDetection(SurProjectCheckDetection surProjectCheckDetection);

    /**
     * 删除材料送检
     * 
     * @param id 材料送检主键
     * @return 结果
     */
    public int deleteSurProjectCheckDetectionById(Long id);

    /**
     * 批量删除材料送检
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSurProjectCheckDetectionByIds(Long[] ids);

    public List<SurProjectCheckDetection> groupByCheckType(SurProjectCheckDetection where);
}
